clc
clearvars
load MeshFiles
%%%%% uncomment the domain that you want
%mesh = SquareHole;  % square w/ hole, dirichlet outside and neumann inside
%mesh = LShape;     % [-1,1]^2\[0,1]^2 w/ dirichlet
%mesh = LShapeFree; % [-1,1]^2\[0,1]^2 w/ dirichlet and neumann
mesh = PiTangle;    % [-pi,pi] x [0,pi] w/ dirichlet

n = 2; % number of eigenvalues to plot
for i = 1:length(mesh)
    coord = mesh(i).coordinates;
    elem = mesh(i).elements;
    
    [MG,KG] = FEM2DLagrangeP1(coord,elem);
    % SOLVING GENERALIZED EIGENVALUE PROBLEM
    U = zeros(size(MG,1),n);
    FN = setdiff(1:size(MG,1),find(mesh(i).coordinates(:,end) == 1));
    %FN = setdiff(FN,find(mesh(i).coordinates(:,end) == 2));
    [UF, W] = eigs(KG(FN,FN),MG(FN,FN),n,'sm');
    U(FN,:) = UF;
    w = sqrt(diag(W));
    
    figure(1)
    tiledlayout(n,1)
    for s = 1:n
        ax(s) = nexttile;
        trisurf(elem,coord(:,1),coord(:,2),U(:,s),'linestyle','none')
    end
    linkprop(ax,{'CameraUpVector', 'CameraPosition', 'CameraTarget', 'XLim', 'YLim'});
    colormap jet
    
    view(3)
    drawnow
    pause(0.5)
end
